summaryrefslogtreecommitdiff
path: root/pool.go
diff options
context:
space:
mode:
Diffstat (limited to 'pool.go')
-rw-r--r--pool.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/pool.go b/pool.go
index e9227889..a7721050 100644
--- a/pool.go
+++ b/pool.go
@@ -19,8 +19,8 @@ const (
// Pool managed set of inner worker processes.
type Pool interface {
- // Observe all caused events to attached watcher.
- Observe(o func(event int, ctx interface{}))
+ // Listen all caused events to attached watcher.
+ Listen(l func(event int, ctx interface{}))
// Exec one task with given payload and context, returns result or error.
Exec(rqs *Payload) (rsp *Payload, err error)